@@ -32,5 +32,17 @@ benches!(
 
 	Bench::new("dactyl::NiceU16", "from(u16::MAX)")
 		.timed(Duration::from_secs(1))
-		.with(|| NiceU16::from(u16::MAX))
+		.with(|| NiceU16::from(u16::MAX)),
+
+	Bench::new("dactyl::NiceU16", "with_separator(40_999, b'_')")
+		.timed(Duration::from_secs(1))
+		.with(|| NiceU16::with_separator(40_999_u16, b'_')),
+
+	Bench::new("dactyl::NiceU16", "as_string()")
+		.timed(Duration::from_secs(1))
+		.with_setup(NiceU16::from(40_999_u16), |c| c.as_string()),
+
+	Bench::new("dactyl::NiceU16", "to_string()")
+		.timed(Duration::from_secs(1))
+		.with_setup(NiceU16::from(40_999_u16), |c| c.to_string()),
 );
